==> cloudwatch-1.60.0-sources.jar: software/amazon/awscdk/services/cloudwatch/CfnCompositeAlarmProps.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * Properties for defining a `AWS::CloudWatch::CompositeAlarm`.
 * <p>
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudwatch-compositealarm.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:02.847Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.CfnCompositeAlarmProps")
@software.amazon.jsii.Jsii.Proxy(CfnCompositeAlarmProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnCompositeAlarmProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::CloudWatch::CompositeAlarm.AlarmName`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudwatch-compositealarm.html#cfn-cloudwatch-compositealarm-alarmname
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getAlarmName();

    /**
     * `AWS::CloudWatch::CompositeAlarm.AlarmRule`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudwatch-compositealarm.html#cfn-cloudwatch-compositealarm-alarmrule
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getAlarmRule();

    /**
     * `AWS::CloudWatch::CompositeAlarm.ActionsEnabled`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudwatch-compositealarm.html#cfn-cloudwatch-compositealarm-actionsenabled
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getActionsEnabled() {
        return null;
    }

    /**
     * `AWS::CloudWatch::CompositeAlarm.AlarmActions`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudwatch-compositealarm.html#cfn-cloudwatch-compositealarm-alarmactions
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getAlarmActions() {
        return null;
    }

    /**
     * `AWS::CloudWatch::CompositeAlarm.AlarmDescription`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudwatch-compositealarm.html#cfn-cloudwatch-compositealarm-alarmdescription
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getAlarmDescription() {
        return null;
    }

    /**
     * `AWS::CloudWatch::CompositeAlarm.InsufficientDataActions`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudwatch-compositealarm.html#cfn-cloudwatch-compositealarm-insufficientdataactions
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getInsufficientDataActions() {
        return null;
    }

    /**
     * `AWS::CloudWatch::CompositeAlarm.OKActions`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudwatch-compositealarm.html#cfn-cloudwatch-compositealarm-okactions
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getOkActions() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnCompositeAlarmProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnCompositeAlarmProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnCompositeAlarmProps> {
        private java.lang.String alarmName;
        private java.lang.String alarmRule;
        private java.lang.Object actionsEnabled;
        private java.util.List<java.lang.String> alarmActions;
        private java.lang.String alarmDescription;
        private java.util.List<java.lang.String> insufficientDataActions;
        private java.util.List<java.lang.String> okActions;

        /**
         * Sets the value of {@link CfnCompositeAlarmProps#getAlarmName}
         * @param alarmName `AWS::CloudWatch::CompositeAlarm.AlarmName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder alarmName(java.lang.String alarmName) {
            this.alarmName = alarmName;
            return this;
        }

        /**
         * Sets the value of {@link CfnCompositeAlarmProps#getAlarmRule}
         * @param alarmRule `AWS::CloudWatch::CompositeAlarm.AlarmRule`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder alarmRule(java.lang.String alarmRule) {
            this.alarmRule = alarmRule;
            return this;
        }

        /**
         * Sets the value of {@link CfnCompositeAlarmProps#getActionsEnabled}
         * @param actionsEnabled `AWS::CloudWatch::CompositeAlarm.ActionsEnabled`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder actionsEnabled(java.lang.Boolean actionsEnabled) {
            this.actionsEnabled = actionsEnabled;
            return this;
        }

        /**
         * Sets the value of {@link CfnCompositeAlarmProps#getActionsEnabled}
         * @param actionsEnabled `AWS::CloudWatch::CompositeAlarm.ActionsEnabled`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder actionsEnabled(software.amazon.awscdk.core.IResolvable actionsEnabled) {
            this.actionsEnabled = actionsEnabled;
            return this;
        }

        /**
         * Sets the value of {@link CfnCompositeAlarmProps#getAlarmActions}
         * @param alarmActions `AWS::CloudWatch::CompositeAlarm.AlarmActions`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder alarmActions(java.util.List<java.lang.String> alarmActions) {
            this.alarmActions = alarmActions;
            return this;
        }

        /**
         * Sets the value of {@link CfnCompositeAlarmProps#getAlarmDescription}
         * @param alarmDescription `AWS::CloudWatch::CompositeAlarm.AlarmDescription`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder alarmDescription(java.lang.String alarmDescription) {
            this.alarmDescription = alarmDescription;
            return this;
        }

        /**
         * Sets the value of {@link CfnCompositeAlarmProps#getInsufficientDataActions}
         * @param insufficientDataActions `AWS::CloudWatch::CompositeAlarm.InsufficientDataActions`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder insufficientDataActions(java.util.List<java.lang.String> insufficientDataActions) {
            this.insufficientDataActions = insufficientDataActions;
            return this;
        }

        /**
         * Sets the value of {@link CfnCompositeAlarmProps#getOkActions}
         * @param okActions `AWS::CloudWatch::CompositeAlarm.OKActions`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder okActions(java.util.List<java.lang.String> okActions) {
            this.okActions = okActions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnCompositeAlarmProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnCompositeAlarmProps build() {
            return new Jsii$Proxy(alarmName, alarmRule, actionsEnabled, alarmActions, alarmDescription, insufficientDataActions, okActions);
        }
    }

    /**
     * An implementation for {@link CfnCompositeAlarmProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnCompositeAlarmProps {
        private final java.lang.String alarmName;
        private final java.lang.String alarmRule;
        private final java.lang.Object actionsEnabled;
        private final java.util.List<java.lang.String> alarmActions;
        private final java.lang.String alarmDescription;
        private final java.util.List<java.lang.String> insufficientDataActions;
        private final java.util.List<java.lang.String> okActions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.alarmName = this.jsiiGet("alarmName", java.lang.String.class);
            this.alarmRule = this.jsiiGet("alarmRule", java.lang.String.class);
            this.actionsEnabled = this.jsiiGet("actionsEnabled", java.lang.Object.class);
            this.alarmActions = this.jsiiGet("alarmActions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.alarmDescription = this.jsiiGet("alarmDescription", java.lang.String.class);
            this.insufficientDataActions = this.jsiiGet("insufficientDataActions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.okActions = this.jsiiGet("okActions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String alarmName, final java.lang.String alarmRule, final java.lang.Object actionsEnabled, final java.util.List<java.lang.String> alarmActions, final java.lang.String alarmDescription, final java.util.List<java.lang.String> insufficientDataActions, final java.util.List<java.lang.String> okActions) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.alarmName = java.util.Objects.requireNonNull(alarmName, "alarmName is required");
            this.alarmRule = java.util.Objects.requireNonNull(alarmRule, "alarmRule is required");
            this.actionsEnabled = actionsEnabled;
            this.alarmActions = alarmActions;
            this.alarmDescription = alarmDescription;
            this.insufficientDataActions = insufficientDataActions;
            this.okActions = okActions;
        }

        @Override
        public java.lang.String getAlarmName() {
            return this.alarmName;
        }

        @Override
        public java.lang.String getAlarmRule() {
            return this.alarmRule;
        }

        @Override
        public java.lang.Object getActionsEnabled() {
            return this.actionsEnabled;
        }

        @Override
        public java.util.List<java.lang.String> getAlarmActions() {
            return this.alarmActions;
        }

        @Override
        public java.lang.String getAlarmDescription() {
            return this.alarmDescription;
        }

        @Override
        public java.util.List<java.lang.String> getInsufficientDataActions() {
            return this.insufficientDataActions;
        }

        @Override
        public java.util.List<java.lang.String> getOkActions() {
            return this.okActions;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("alarmName", om.valueToTree(this.getAlarmName()));
            data.set("alarmRule", om.valueToTree(this.getAlarmRule()));
            if (this.getActionsEnabled() != null) {
                data.set("actionsEnabled", om.valueToTree(this.getActionsEnabled()));
            }
            if (this.getAlarmActions() != null) {
                data.set("alarmActions", om.valueToTree(this.getAlarmActions()));
            }
            if (this.getAlarmDescription() != null) {
                data.set("alarmDescription", om.valueToTree(this.getAlarmDescription()));
            }
            if (this.getInsufficientDataActions() != null) {
                data.set("insufficientDataActions", om.valueToTree(this.getInsufficientDataActions()));
            }
            if (this.getOkActions() != null) {
                data.set("okActions", om.valueToTree(this.getOkActions()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudwatch.CfnCompositeAlarmProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnCompositeAlarmProps.Jsii$Proxy that = (CfnCompositeAlarmProps.Jsii$Proxy) o;

            if (!alarmName.equals(that.alarmName)) return false;
            if (!alarmRule.equals(that.alarmRule)) return false;
            if (this.actionsEnabled != null ? !this.actionsEnabled.equals(that.actionsEnabled) : that.actionsEnabled != null) return false;
            if (this.alarmActions != null ? !this.alarmActions.equals(that.alarmActions) : that.alarmActions != null) return false;
            if (this.alarmDescription != null ? !this.alarmDescription.equals(that.alarmDescription) : that.alarmDescription != null) return false;
            if (this.insufficientDataActions != null ? !this.insufficientDataActions.equals(that.insufficientDataActions) : that.insufficientDataActions != null) return false;
            return this.okActions != null ? this.okActions.equals(that.okActions) : that.okActions == null;
        }

        @Override
        public int hashCode() {
            int result = this.alarmName.hashCode();
            result = 31 * result + (this.alarmRule.hashCode());
            result = 31 * result + (this.actionsEnabled != null ? this.actionsEnabled.hashCode() : 0);
            result = 31 * result + (this.alarmActions != null ? this.alarmActions.hashCode() : 0);
            result = 31 * result + (this.alarmDescription != null ? this.alarmDescription.hashCode() : 0);
            result = 31 * result + (this.insufficientDataActions != null ? this.insufficientDataActions.hashCode() : 0);
            result = 31 * result + (this.okActions != null ? this.okActions.hashCode() : 0);
            return result;
        }
    }
}

==> cloudwatch-1.93.0-sources.jar: software/amazon/awscdk/services/cloudwatch/CfnCompositeAlarmProps.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * Properties for defining a `AWS::CloudWatch::CompositeAlarm`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:22.281Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.CfnCompositeAlarmProps")
@software.amazon.jsii.Jsii.Proxy(CfnCompositeAlarmProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnCompositeAlarmProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::CloudWatch::CompositeAlarm.AlarmName`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getAlarmName();

    /**
     * `AWS::CloudWatch::CompositeAlarm.AlarmRule`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getAlarmRule();

    /**
     * `AWS::CloudWatch::CompositeAlarm.ActionsEnabled`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getActionsEnabled() {
        return null;
    }

    /**
     * `AWS::CloudWatch::CompositeAlarm.AlarmActions`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getAlarmActions() {
        return null;
    }

    /**
     * `AWS::CloudWatch::CompositeAlarm.AlarmDescription`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getAlarmDescription() {
        return null;
    }

    /**
     * `AWS::CloudWatch::CompositeAlarm.InsufficientDataActions`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getInsufficientDataActions() {
        return null;
    }

    /**
     * `AWS::CloudWatch::CompositeAlarm.OKActions`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getOkActions() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnCompositeAlarmProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnCompositeAlarmProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnCompositeAlarmProps> {
        private java.lang.String alarmName;
        private java.lang.String alarmRule;
        private java.lang.Object actionsEnabled;
        private java.util.List<java.lang.String> alarmActions;
        private java.lang.String alarmDescription;
        private java.util.List<java.lang.String> insufficientDataActions;
        private java.util.List<java.lang.String> okActions;

        /**
         * Sets the value of {@link CfnCompositeAlarmProps#getAlarmName}
         * @param alarmName `AWS::CloudWatch::CompositeAlarm.AlarmName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder alarmName(java.lang.String alarmName) {
            this.alarmName = alarmName;
            return this;
        }

        /**
         * Sets the value of {@link CfnCompositeAlarmProps#getAlarmRule}
         * @param alarmRule `AWS::CloudWatch::CompositeAlarm.AlarmRule`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder alarmRule(java.lang.String alarmRule) {
            this.alarmRule = alarmRule;
            return this;
        }

        /**
         * Sets the value of {@link CfnCompositeAlarmProps#getActionsEnabled}
         * @param actionsEnabled `AWS::CloudWatch::CompositeAlarm.ActionsEnabled`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder actionsEnabled(java.lang.Boolean actionsEnabled) {
            this.actionsEnabled = actionsEnabled;
            return this;
        }

        /**
         * Sets the value of {@link CfnCompositeAlarmProps#getActionsEnabled}
         * @param actionsEnabled `AWS::CloudWatch::CompositeAlarm.ActionsEnabled`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder actionsEnabled(software.amazon.awscdk.core.IResolvable actionsEnabled) {
            this.actionsEnabled = actionsEnabled;
            return this;
        }

        /**
         * Sets the value of {@link CfnCompositeAlarmProps#getAlarmActions}
         * @param alarmActions `AWS::CloudWatch::CompositeAlarm.AlarmActions`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder alarmActions(java.util.List<java.lang.String> alarmActions) {
            this.alarmActions = alarmActions;
            return this;
        }

        /**
         * Sets the value of {@link CfnCompositeAlarmProps#getAlarmDescription}
         * @param alarmDescription `AWS::CloudWatch::CompositeAlarm.AlarmDescription`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder alarmDescription(java.lang.String alarmDescription) {
            this.alarmDescription = alarmDescription;
            return this;
        }

        /**
         * Sets the value of {@link CfnCompositeAlarmProps#getInsufficientDataActions}
         * @param insufficientDataActions `AWS::CloudWatch::CompositeAlarm.InsufficientDataActions`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder insufficientDataActions(java.util.List<java.lang.String> insufficientDataActions) {
            this.insufficientDataActions = insufficientDataActions;
            return this;
        }

        /**
         * Sets the value of {@link CfnCompositeAlarmProps#getOkActions}
         * @param okActions `AWS::CloudWatch::CompositeAlarm.OKActions`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder okActions(java.util.List<java.lang.String> okActions) {
            this.okActions = okActions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnCompositeAlarmProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnCompositeAlarmProps build() {
            return new Jsii$Proxy(alarmName, alarmRule, actionsEnabled, alarmActions, alarmDescription, insufficientDataActions, okActions);
        }
    }

    /**
     * An implementation for {@link CfnCompositeAlarmProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnCompositeAlarmProps {
        private final java.lang.String alarmName;
        private final java.lang.String alarmRule;
        private final java.lang.Object actionsEnabled;
        private final java.util.List<java.lang.String> alarmActions;
        private final java.lang.String alarmDescription;
        private final java.util.List<java.lang.String> insufficientDataActions;
        private final java.util.List<java.lang.String> okActions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.alarmName = software.amazon.jsii.Kernel.get(this, "alarmName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.alarmRule = software.amazon.jsii.Kernel.get(this, "alarmRule", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.actionsEnabled = software.amazon.jsii.Kernel.get(this, "actionsEnabled", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.alarmActions = software.amazon.jsii.Kernel.get(this, "alarmActions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.alarmDescription = software.amazon.jsii.Kernel.get(this, "alarmDescription", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.insufficientDataActions = software.amazon.jsii.Kernel.get(this, "insufficientDataActions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.okActions = software.amazon.jsii.Kernel.get(this, "okActions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String alarmName, final java.lang.String alarmRule, final java.lang.Object actionsEnabled, final java.util.List<java.lang.String> alarmActions, final java.lang.String alarmDescription, final java.util.List<java.lang.String> insufficientDataActions, final java.util.List<java.lang.String> okActions) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.alarmName = java.util.Objects.requireNonNull(alarmName, "alarmName is required");
            this.alarmRule = java.util.Objects.requireNonNull(alarmRule, "alarmRule is required");
            this.actionsEnabled = actionsEnabled;
            this.alarmActions = alarmActions;
            this.alarmDescription = alarmDescription;
            this.insufficientDataActions = insufficientDataActions;
            this.okActions = okActions;
        }

        @Override
        public final java.lang.String getAlarmName() {
            return this.alarmName;
        }

        @Override
        public final java.lang.String getAlarmRule() {
            return this.alarmRule;
        }

        @Override
        public final java.lang.Object getActionsEnabled() {
            return this.actionsEnabled;
        }

        @Override
        public final java.util.List<java.lang.String> getAlarmActions() {
            return this.alarmActions;
        }

        @Override
        public final java.lang.String getAlarmDescription() {
            return this.alarmDescription;
        }

        @Override
        public final java.util.List<java.lang.String> getInsufficientDataActions() {
            return this.insufficientDataActions;
        }

        @Override
        public final java.util.List<java.lang.String> getOkActions() {
            return this.okActions;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("alarmName", om.valueToTree(this.getAlarmName()));
            data.set("alarmRule", om.valueToTree(this.getAlarmRule()));
            if (this.getActionsEnabled() != null) {
                data.set("actionsEnabled", om.valueToTree(this.getActionsEnabled()));
            }
            if (this.getAlarmActions() != null) {
                data.set("alarmActions", om.valueToTree(this.getAlarmActions()));
            }
            if (this.getAlarmDescription() != null) {
                data.set("alarmDescription", om.valueToTree(this.getAlarmDescription()));
            }
            if (this.getInsufficientDataActions() != null) {
                data.set("insufficientDataActions", om.valueToTree(this.getInsufficientDataActions()));
            }
            if (this.getOkActions() != null) {
                data.set("okActions", om.valueToTree(this.getOkActions()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudwatch.CfnCompositeAlarmProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnCompositeAlarmProps.Jsii$Proxy that = (CfnCompositeAlarmProps.Jsii$Proxy) o;

            if (!alarmName.equals(that.alarmName)) return false;
            if (!alarmRule.equals(that.alarmRule)) return false;
            if (this.actionsEnabled != null ? !this.actionsEnabled.equals(that.actionsEnabled) : that.actionsEnabled != null) return false;
            if (this.alarmActions != null ? !this.alarmActions.equals(that.alarmActions) : that.alarmActions != null) return false;
            if (this.alarmDescription != null ? !this.alarmDescription.equals(that.alarmDescription) : that.alarmDescription != null) return false;
            if (this.insufficientDataActions != null ? !this.insufficientDataActions.equals(that.insufficientDataActions) : that.insufficientDataActions != null) return false;
            return this.okActions != null ? this.okActions.equals(that.okActions) : that.okActions == null;
        }

        @Override
        public final int hashCode() {
            int result = this.alarmName.hashCode();
            result = 31 * result + (this.alarmRule.hashCode());
            result = 31 * result + (this.actionsEnabled != null ? this.actionsEnabled.hashCode() : 0);
            result = 31 * result + (this.alarmActions != null ? this.alarmActions.hashCode() : 0);
            result = 31 * result + (this.alarmDescription != null ? this.alarmDescription.hashCode() : 0);
            result = 31 * result + (this.insufficientDataActions != null ? this.insufficientDataActions.hashCode() : 0);
            result = 31 * result + (this.okActions != null ? this.okActions.hashCode() : 0);
            return result;
        }
    }
}
